mafw.tools.pandas\_tools
========================

.. automodule:: mafw.tools.pandas_tools

   
   .. rubric:: Functions

   .. autosummary::
   
      group_and_aggregate_data_frame
      slice_data_frame
   